@@ -1,6 +1,6 @@
 /* ide-buildsystem-plugin.c
  *
- * Copyright © 2016 Matthew Leeds <mleeds@redhat.com>
+ * Copyright 2016 Matthew Leeds <mleeds@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,18 @@
 
 #define G_LOG_DOMAIN "ide-buildsystem-plugin"
 
+#include "config.h"
+
 #include <libpeas/peas.h>
 
+#include "ide-version-macros.h"
+
 #include "buildconfig/ide-buildconfig-configuration-provider.h"
 #include "buildconfig/ide-buildconfig-pipeline-addin.h"
 #include "buildsystem/ide-build-pipeline-addin.h"
 #include "config/ide-configuration-provider.h"
 
-void
+_IDE_EXTERN void
 ide_buildconfig_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module,
