@@ -1,6 +1,6 @@
 /* ide-build-manager.c
  *
- * Copyright © 2016-2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016-2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-build-manager"
 
+#include "config.h"
+
 #include <dazzle.h>
 #include <glib/gi18n.h>
 
@@ -38,6 +40,7 @@
 #include "runtimes/ide-runtime.h"
 #include "runtimes/ide-runtime-manager.h"
 #include "runtimes/ide-runtime-private.h"
+#include "threading/ide-task.h"
 #include "vcs/ide-vcs.h"
 
 /**
@@ -330,7 +333,7 @@ ide_build_manager_ensure_runtime_cb (GObject      *object,
 {
   IdeRuntimeManager *runtime_manager = (IdeRuntimeManager *)object;
   g_autoptr(GError) error = NULL;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   IdeBuildPipeline *pipeline;
   IdeBuildManager *self;
   GCancellable *cancellable;
@@ -339,10 +342,10 @@ ide_build_manager_ensure_runtime_cb (GObject      *object,
 
   g_assert (IDE_IS_RUNTIME_MANAGER (runtime_manager));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
-  self = g_task_get_source_object (task);
-  pipeline = g_task_get_task_data (task);
+  self = ide_task_get_source_object (task);
+  pipeline = ide_task_get_task_data (task);
 
   g_assert (IDE_IS_BUILD_MANAGER (self));
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
@@ -359,10 +362,10 @@ ide_build_manager_ensure_runtime_cb (GObject      *object,
       IDE_GOTO (failure);
     }
 
-  if (g_task_return_error_if_cancelled (task))
+  if (ide_task_return_error_if_cancelled (task))
     IDE_GOTO (failure);
 
-  cancellable = g_task_get_cancellable (task);
+  cancellable = ide_task_get_cancellable (task);
 
   /* This will cause plugins to load on the pipeline. */
   if (!g_initable_init (G_INITABLE (pipeline), cancellable, &error))
@@ -378,19 +381,19 @@ ide_build_manager_ensure_runtime_cb (GObject      *object,
 
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_PIPELINE]);
 
-  g_task_return_boolean (task, TRUE);
+  ide_task_return_boolean (task, TRUE);
 
   IDE_EXIT;
 
 failure:
 
   if (error != NULL)
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
-    g_task_return_new_error (task,
-                             G_IO_ERROR,
-                             G_IO_ERROR_FAILED,
-                             "Failed to setup build pipeline");
+    ide_task_return_new_error (task,
+                               G_IO_ERROR,
+                               G_IO_ERROR_FAILED,
+                               "Failed to setup build pipeline");
 
   IDE_EXIT;
 }
@@ -403,7 +406,7 @@ ide_build_manager_device_get_info_cb (GObject      *object,
   IdeDevice *device = (IdeDevice *)object;
   g_autoptr(IdeDeviceInfo) info = NULL;
   g_autoptr(GError) error = NULL;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   IdeRuntimeManager *runtime_manager;
   IdeBuildPipeline *pipeline;
   IdeContext *context;
@@ -412,9 +415,9 @@ ide_build_manager_device_get_info_cb (GObject      *object,
 
   g_assert (IDE_IS_DEVICE (device));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
-  pipeline = g_task_get_task_data (task);
+  pipeline = ide_task_get_task_data (task);
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
 
   context = ide_object_get_context (IDE_OBJECT (pipeline));
@@ -428,7 +431,7 @@ ide_build_manager_device_get_info_cb (GObject      *object,
       ide_context_warning (context,
                            _("Failed to get device information: %s"),
                            error->message);
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -436,7 +439,7 @@ ide_build_manager_device_get_info_cb (GObject      *object,
 
   _ide_runtime_manager_prepare_async (runtime_manager,
                                       pipeline,
-                                      g_task_get_cancellable (task),
+                                      ide_task_get_cancellable (task),
                                       ide_build_manager_ensure_runtime_cb,
                                       g_object_ref (task));
 
@@ -446,7 +449,7 @@ ide_build_manager_device_get_info_cb (GObject      *object,
 static void
 ide_build_manager_invalidate_pipeline (IdeBuildManager *self)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   IdeConfigurationManager *config_manager;
   IdeDeviceManager *device_manager;
   IdeConfiguration *config;
@@ -517,9 +520,9 @@ ide_build_manager_invalidate_pipeline (IdeBuildManager *self)
   /*
    * Create a task to manage our async pipeline initialization state.
    */
-  task = g_task_new (self, self->cancellable, NULL, NULL);
-  g_task_set_task_data (task, g_object_ref (self->pipeline), g_object_unref);
-  g_task_set_priority (task, G_PRIORITY_LOW);
+  task = ide_task_new (self, self->cancellable, NULL, NULL);
+  ide_task_set_task_data (task, g_object_ref (self->pipeline), g_object_unref);
+  ide_task_set_priority (task, G_PRIORITY_LOW);
 
   /*
    * Next, we need to get information on the build device, which may require
@@ -688,8 +691,6 @@ ide_build_manager_real_build_finished (IdeBuildManager  *self,
 
       ide_diagnostics_manager_rediagnose (diagnostics, buffer);
     }
-
-  self->needs_rediagnose = FALSE;
 }
 
 static void
@@ -1072,7 +1073,6 @@ ide_build_manager_init (IdeBuildManager *self)
   ide_build_manager_update_action_enabled (self);
 
   self->cancellable = g_cancellable_new ();
-  self->needs_rediagnose = TRUE;
 
   self->pipeline_signals = dzl_signal_group_new (IDE_TYPE_BUILD_PIPELINE);
 
@@ -1255,23 +1255,23 @@ ide_build_manager_execute_cb (GObject      *object,
                               gpointer      user_data)
 {
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
 
   IDE_ENTRY;
 
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   if (!ide_build_pipeline_execute_finish (pipeline, result, &error))
     {
       ide_object_warning (pipeline, "%s", error->message);
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       IDE_GOTO (failure);
     }
 
-  g_task_return_boolean (task, TRUE);
+  ide_task_return_boolean (task, TRUE);
 
 failure:
   IDE_EXIT;
@@ -1283,7 +1283,7 @@ ide_build_manager_save_all_cb (GObject      *object,
                                gpointer      user_data)
 {
   IdeBufferManager *buffer_manager = (IdeBufferManager *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
   IdeBuildManager *self;
   GCancellable *cancellable;
@@ -1291,17 +1291,17 @@ ide_build_manager_save_all_cb (GObject      *object,
   IDE_ENTRY;
 
   g_assert (IDE_IS_BUFFER_MANAGER (buffer_manager));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
-  self = g_task_get_source_object (task);
-  cancellable = g_task_get_cancellable (task);
+  self = ide_task_get_source_object (task);
+  cancellable = ide_task_get_cancellable (task);
 
   g_assert (IDE_IS_BUILD_MANAGER (self));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   if (!ide_buffer_manager_save_all_finish (buffer_manager, result, &error))
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -1339,7 +1339,7 @@ ide_build_manager_execute_async (IdeBuildManager     *self,
                                  GAsyncReadyCallback  callback,
                                  gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   IdeBufferManager *buffer_manager;
   IdeContext *context;
 
@@ -1351,25 +1351,25 @@ ide_build_manager_execute_async (IdeBuildManager     *self,
 
   cancellable = dzl_cancellable_chain (cancellable, self->cancellable);
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_build_manager_execute_async);
-  g_task_set_priority (task, G_PRIORITY_LOW);
-  g_task_set_return_on_cancel (task, TRUE);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_build_manager_execute_async);
+  ide_task_set_priority (task, G_PRIORITY_LOW);
+  ide_task_set_return_on_cancel (task, TRUE);
 
   if (self->pipeline == NULL ||
       self->can_build == FALSE ||
       !ide_build_pipeline_is_ready (self->pipeline))
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_PENDING,
-                               "Cannot execute pipeline, it has not yet been prepared");
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_PENDING,
+                                 "Cannot execute pipeline, it has not yet been prepared");
       IDE_EXIT;
     }
 
   if (!ide_build_pipeline_request_phase (self->pipeline, phase))
     {
-      g_task_return_boolean (task, TRUE);
+      ide_task_return_boolean (task, TRUE);
       IDE_EXIT;
     }
 
@@ -1440,9 +1440,9 @@ ide_build_manager_execute_finish (IdeBuildManager  *self,
   IDE_ENTRY;
 
   g_return_val_if_fail (IDE_IS_BUILD_MANAGER (self), FALSE);
-  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+  g_return_val_if_fail (IDE_IS_TASK (result), FALSE);
 
-  ret = g_task_propagate_boolean (G_TASK (result), error);
+  ret = ide_task_propagate_boolean (IDE_TASK (result), error);
 
   IDE_RETURN (ret);
 }
@@ -1453,19 +1453,19 @@ ide_build_manager_clean_cb (GObject      *object,
                             gpointer      user_data)
 {
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
 
   IDE_ENTRY;
 
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   if (!ide_build_pipeline_clean_finish (pipeline, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
-    g_task_return_boolean (task, TRUE);
+    ide_task_return_boolean (task, TRUE);
 }
 
 /**
@@ -1489,7 +1489,7 @@ ide_build_manager_clean_async (IdeBuildManager     *self,
                                GAsyncReadyCallback  callback,
                                gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
 
   IDE_ENTRY;
 
@@ -1499,17 +1499,17 @@ ide_build_manager_clean_async (IdeBuildManager     *self,
 
   cancellable = dzl_cancellable_chain (cancellable, self->cancellable);
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_build_manager_clean_async);
-  g_task_set_priority (task, G_PRIORITY_LOW);
-  g_task_set_return_on_cancel (task, TRUE);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_build_manager_clean_async);
+  ide_task_set_priority (task, G_PRIORITY_LOW);
+  ide_task_set_return_on_cancel (task, TRUE);
 
   if (self->pipeline == NULL)
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_PENDING,
-                               "Cannot execute pipeline, it has not yet been prepared");
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_PENDING,
+                                 "Cannot execute pipeline, it has not yet been prepared");
       IDE_EXIT;
     }
 
@@ -1552,9 +1552,9 @@ ide_build_manager_clean_finish (IdeBuildManager  *self,
   IDE_ENTRY;
 
   g_return_val_if_fail (IDE_IS_BUILD_MANAGER (self), FALSE);
-  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+  g_return_val_if_fail (IDE_IS_TASK (result), FALSE);
 
-  ret = g_task_propagate_boolean (G_TASK (result), error);
+  ret = ide_task_propagate_boolean (IDE_TASK (result), error);
 
   IDE_RETURN (ret);
 }
@@ -1565,19 +1565,19 @@ ide_build_manager_rebuild_cb (GObject      *object,
                               gpointer      user_data)
 {
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
 
   IDE_ENTRY;
 
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   if (!ide_build_pipeline_rebuild_finish (pipeline, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
-    g_task_return_boolean (task, TRUE);
+    ide_task_return_boolean (task, TRUE);
 
   IDE_EXIT;
 }
@@ -1605,7 +1605,7 @@ ide_build_manager_rebuild_async (IdeBuildManager     *self,
                                  GAsyncReadyCallback  callback,
                                  gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
 
   IDE_ENTRY;
 
@@ -1615,17 +1615,17 @@ ide_build_manager_rebuild_async (IdeBuildManager     *self,
 
   cancellable = dzl_cancellable_chain (cancellable, self->cancellable);
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_build_manager_rebuild_async);
-  g_task_set_priority (task, G_PRIORITY_LOW);
-  g_task_set_return_on_cancel (task, TRUE);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_build_manager_rebuild_async);
+  ide_task_set_priority (task, G_PRIORITY_LOW);
+  ide_task_set_return_on_cancel (task, TRUE);
 
   if (self->pipeline == NULL)
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_PENDING,
-                               "Cannot execute pipeline, it has not yet been prepared");
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_PENDING,
+                                 "Cannot execute pipeline, it has not yet been prepared");
       IDE_EXIT;
     }
 
@@ -1660,9 +1660,9 @@ ide_build_manager_rebuild_finish (IdeBuildManager  *self,
   IDE_ENTRY;
 
   g_return_val_if_fail (IDE_IS_BUILD_MANAGER (self), FALSE);
-  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+  g_return_val_if_fail (IDE_IS_TASK (result), FALSE);
 
-  ret = g_task_propagate_boolean (G_TASK (result), error);
+  ret = ide_task_propagate_boolean (IDE_TASK (result), error);
 
   IDE_RETURN (ret);
 }
