@@ -1,6 +1,6 @@
 /* ide-build-plugin.c
  *
- * Copyright © 2015 Christian Hergert <chergert@redhat.com>
+ * Copyright 2015 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,16 @@
 
 #define G_LOG_DOMAIN "ide-build-plugin"
 
-#include <libpeas/peas.h>
-#include <ide.h>
+#include "config.h"
 
-#include "buildui/ide-build-tool.h"
+#include <libpeas/peas.h>
+
+#include "ide-version-macros.h"
+
+#include "workbench/ide-workbench-addin.h"
 #include "buildui/ide-build-workbench-addin.h"
 
-void
+_IDE_EXTERN void
 ide_build_tool_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module,
