@@ -1,6 +1,6 @@
 /* ide-configuration.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-configuration"
 
+#include "config.h"
+
 #include <string.h>
 
 #include "ide-context.h"
@@ -952,6 +954,7 @@ ide_configuration_set_environment (IdeConfiguration *self,
   IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
 
   g_return_if_fail (IDE_IS_CONFIGURATION (self));
+  g_return_if_fail (!environment || IDE_IS_ENVIRONMENT (environment));
 
   if (priv->environment != environment)
     {
