@@ -1,6 +1,6 @@
 /* ide-debugger-editor-addin.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-debugger-editor-addin"
 
+#include "config.h"
+
 #include <glib/gi18n.h>
 
 #include "ide-context.h"
@@ -105,12 +107,8 @@ debugger_log (IdeDebuggerEditorAddin *self,
       while (NULL != (line = ide_line_reader_next (&reader, &line_len)))
         {
           vte_terminal_feed (VTE_TERMINAL (self->log_view), line, line_len);
-
-          if ((line + line_len) < (str + len))
-            {
-              if (line[line_len] == '\r' || line[line_len] == '\n')
-                vte_terminal_feed (VTE_TERMINAL (self->log_view), "\r\n", 2);
-            }
+          if (line[line_len] == '\r' || line[line_len] == '\n')
+            vte_terminal_feed (VTE_TERMINAL (self->log_view), "\r\n", 2);
         }
     }
 }
