@@ -1,6 +1,6 @@
 /* ide-fixit.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "dazzle.h"
+#define G_LOG_DOMAIN "ide-fixit"
+
+#include "config.h"
+
+#include <dazzle.h>
 
 #include "diagnostics/ide-fixit.h"
 #include "diagnostics/ide-source-range.h"
