@@ -1,6 +1,6 @@
 /* ide.h
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,7 +46,6 @@ G_BEGIN_DECLS
 #include "buffers/ide-unsaved-file.h"
 #include "buffers/ide-unsaved-files.h"
 #include "buildconfig/ide-buildconfig-configuration.h"
-#include "buildconfig/ide-buildconfig-configuration-provider.h"
 #include "buildsystem/ide-build-manager.h"
 #include "buildsystem/ide-build-pipeline.h"
 #include "buildsystem/ide-build-pipeline-addin.h"
@@ -62,6 +61,7 @@ G_BEGIN_DECLS
 #include "buildsystem/ide-dependency-updater.h"
 #include "buildsystem/ide-environment-variable.h"
 #include "buildsystem/ide-environment.h"
+#include "buildsystem/ide-simple-build-target.h"
 #include "config/ide-configuration.h"
 #include "config/ide-configuration-manager.h"
 #include "config/ide-configuration-provider.h"
@@ -150,6 +150,7 @@ G_BEGIN_DECLS
 #include "search/ide-tagged-entry.h"
 #include "snippets/ide-source-snippet-chunk.h"
 #include "snippets/ide-source-snippet-context.h"
+#include "snippets/ide-source-snippet-parser.h"
 #include "snippets/ide-source-snippet.h"
 #include "snippets/ide-source-snippets-manager.h"
 #include "snippets/ide-source-snippets.h"
@@ -161,6 +162,8 @@ G_BEGIN_DECLS
 #include "sourceview/ide-source-map.h"
 #include "sourceview/ide-source-style-scheme.h"
 #include "sourceview/ide-source-view.h"
+#include "storage/ide-persistent-map.h"
+#include "storage/ide-persistent-map-builder.h"
 #include "subprocess/ide-subprocess.h"
 #include "subprocess/ide-subprocess-launcher.h"
 #include "symbols/ide-code-indexer.h"
@@ -192,6 +195,8 @@ G_BEGIN_DECLS
 #include "util/ide-posix.h"
 #include "util/ide-progress.h"
 #include "util/ide-ref-ptr.h"
+#include "util/ide-settings.h"
+#include "util/ide-triplet.h"
 #include "util/ide-uri.h"
 #include "vcs/ide-vcs-config.h"
 #include "vcs/ide-vcs-file-info.h"
