@@ -1,6 +1,6 @@
 /* ide-layout-grid.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-layout-grid"
 
+#include "config.h"
+
 #include <string.h>
 
 #include "ide-object.h"
@@ -441,17 +443,6 @@ ide_layout_grid_remove (GtkContainer *container,
     }
 }
 
-static inline gboolean
-rect_contains_point (cairo_rectangle_int_t *rect,
-                     gint                   x,
-                     gint                   y)
-{
-  return x >= rect->x &&
-         y >= rect->y &&
-         x <= (rect->x + rect->width) &&
-         y <= (rect->y + rect->height);
-}
-
 static gboolean
 ide_layout_grid_get_drop_area (IdeLayoutGrid        *self,
                                gint                  x,
