@@ -1,6 +1,6 @@
 /* ide-layout-view.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,12 @@
 
 #define G_LOG_DOMAIN "ide-layout-view"
 
+#include "config.h"
+
 #include <string.h>
 
 #include "layout/ide-layout-view.h"
+#include "threading/ide-task.h"
 
 typedef struct
 {
@@ -67,15 +70,15 @@ ide_layout_view_real_agree_to_close_async (IdeLayoutView       *self,
                                            GAsyncReadyCallback  callback,
                                            gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
 
   g_assert (IDE_IS_LAYOUT_VIEW (self));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_priority (task, G_PRIORITY_LOW);
-  g_task_set_source_tag (task, ide_layout_view_agree_to_close_async);
-  g_task_return_boolean (task, TRUE);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_priority (task, G_PRIORITY_LOW);
+  ide_task_set_source_tag (task, ide_layout_view_agree_to_close_async);
+  ide_task_return_boolean (task, TRUE);
 }
 
 static gboolean
@@ -84,9 +87,9 @@ ide_layout_view_real_agree_to_close_finish (IdeLayoutView  *self,
                                             GError        **error)
 {
   g_assert (IDE_IS_LAYOUT_VIEW (self));
-  g_assert (G_IS_TASK (result));
+  g_assert (IDE_IS_TASK (result));
 
-  return g_task_propagate_boolean (G_TASK (result), error);
+  return ide_task_propagate_boolean (IDE_TASK (result), error);
 }
 
 static void
