@@ -1,7 +1,7 @@
 /* GIO - GLib Input, Output and Streaming Library
  *
- * Copyright © 2012, 2013, 2016 Red Hat, Inc.
- * Copyright © 2012, 2013 Canonical Limited
+ * Copyright 2012, 2013, 2016 Red Hat, Inc.
+ * Copyright 2012, 2013 Canonical Limited
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-breakout-subprocess"
 
+#include "config.h"
+
 #include <dazzle.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -1788,5 +1790,5 @@ _ide_breakout_subprocess_new (const gchar                 *cwd,
   if (!g_initable_init (G_INITABLE (ret), cancellable, error))
     return NULL;
 
-  return IDE_SUBPROCESS (g_steal_pointer (&ret));
+  return g_steal_pointer (&ret);
 }
