@@ -1,6 +1,6 @@
 /* ide-terminal.c
  *
- * Copyright © 2016-2017 Christian Hergert <christian@hergert.me>
+ * Copyright 2016-2017 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define G_LOG_DOMAIN "ide-terminal"
+
+#include "config.h"
+
 #include <dazzle.h>
 #include <glib/gi18n.h>
 #include <ide.h>
