@@ -1,6 +1,6 @@
 /* ide-glib.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 #define G_LOG_DOMAIN "ide-glib"
 
-#include <dazzle.h>
 #include <string.h>
 
 #include "config.h"
@@ -27,6 +26,7 @@
 #include "util/ide-glib.h"
 #include "subprocess/ide-subprocess.h"
 #include "subprocess/ide-subprocess-launcher.h"
+#include "threading/ide-task.h"
 #include "vcs/ide-vcs.h"
 
 typedef struct
@@ -275,7 +275,7 @@ typedef struct
 } GetChildren;
 
 static void
-ide_g_file_get_children_worker (GTask        *task,
+ide_g_file_get_children_worker (IdeTask      *task,
                                 gpointer      source_object,
                                 gpointer      task_data,
                                 GCancellable *cancellable)
@@ -286,7 +286,7 @@ ide_g_file_get_children_worker (GTask        *task,
   GetChildren *gc = task_data;
   GFile *dir = source_object;
 
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
   g_assert (G_IS_FILE (dir));
   g_assert (gc != NULL);
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
@@ -301,7 +301,7 @@ ide_g_file_get_children_worker (GTask        *task,
 
   if (enumerator == NULL)
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       return;
     }
 
@@ -313,7 +313,7 @@ ide_g_file_get_children_worker (GTask        *task,
 
       if (error != NULL)
         {
-          g_task_return_error (task, g_steal_pointer (&error));
+          ide_task_return_error (task, g_steal_pointer (&error));
           return;
         }
 
@@ -323,9 +323,9 @@ ide_g_file_get_children_worker (GTask        *task,
       g_ptr_array_add (children, g_steal_pointer (&file_info));
     }
 
-  g_task_return_pointer (task,
-                         g_steal_pointer (&children),
-                         (GDestroyNotify) g_ptr_array_unref);
+  ide_task_return_pointer (task,
+                           g_steal_pointer (&children),
+                           (GDestroyNotify) g_ptr_array_unref);
 }
 
 static void
@@ -364,7 +364,7 @@ ide_g_file_get_children_async (GFile               *file,
                                GAsyncReadyCallback  callback,
                                gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   GetChildren *gc;
 
   g_return_if_fail (G_IS_FILE (file));
@@ -375,11 +375,11 @@ ide_g_file_get_children_async (GFile               *file,
   gc->attributes = g_strdup (attributes);
   gc->flags = flags;
 
-  task = g_task_new (file, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_g_file_get_children_async);
-  g_task_set_priority (task, io_priority);
-  g_task_set_task_data (task, gc, get_children_free);
-  g_task_run_in_thread (task, ide_g_file_get_children_worker);
+  task = ide_task_new (file, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_g_file_get_children_async);
+  ide_task_set_priority (task, io_priority);
+  ide_task_set_task_data (task, gc, get_children_free);
+  ide_task_run_in_thread (task, ide_g_file_get_children_worker);
 }
 
 /**
@@ -403,33 +403,19 @@ ide_g_file_get_children_finish (GFile         *file,
   GPtrArray *ret;
 
   g_return_val_if_fail (G_IS_FILE (file), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
-  g_return_val_if_fail (g_task_is_valid (G_TASK (result), file), NULL);
+  g_return_val_if_fail (IDE_IS_TASK (result), NULL);
+  g_return_val_if_fail (ide_task_is_valid (IDE_TASK (result), file), NULL);
 
-  ret = g_task_propagate_pointer (G_TASK (result), error);
+  ret = ide_task_propagate_pointer (IDE_TASK (result), error);
 
   return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
-typedef struct
-{
-  GPatternSpec *spec;
-  guint         depth;
-} Find;
-
-static void
-find_free (Find *f)
-{
-  g_clear_pointer (&f->spec, g_pattern_spec_free);
-  g_slice_free (Find, f);
-}
-
 static void
 populate_descendants_matching (GFile        *file,
                                GCancellable *cancellable,
                                GPtrArray    *results,
-                               GPatternSpec *spec,
-                               guint         depth)
+                               GPatternSpec *spec)
 {
   g_autoptr(GFileEnumerator) enumerator = NULL;
   g_autoptr(GPtrArray) children = NULL;
@@ -438,9 +424,6 @@ populate_descendants_matching (GFile        *file,
   g_assert (results != NULL);
   g_assert (spec != NULL);
 
-  if (depth == 0)
-    return;
-
   enumerator = g_file_enumerate_children (file,
                                           G_FILE_ATTRIBUTE_STANDARD_NAME","
                                           G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK","
@@ -485,88 +468,29 @@ populate_descendants_matching (GFile        *file,
 
           /* Don't recurse into known bad directories */
           if (!ide_vcs_is_ignored (NULL, child, NULL))
-            populate_descendants_matching (child, cancellable, results, spec, depth - 1);
+            populate_descendants_matching (child, cancellable, results, spec);
         }
     }
 }
 
 static void
-ide_g_file_find_worker (GTask        *task,
+ide_g_file_find_worker (IdeTask      *task,
                         gpointer      source_object,
                         gpointer      task_data,
                         GCancellable *cancellable)
 {
   GFile *file = source_object;
-  Find *f = task_data;
+  GPatternSpec *spec = task_data;
   g_autoptr(GPtrArray) ret = NULL;
 
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
   g_assert (G_IS_FILE (file));
-  g_assert (f != NULL);
-  g_assert (f->spec != NULL);
+  g_assert (spec != NULL);
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   ret = g_ptr_array_new_with_free_func (g_object_unref);
-  populate_descendants_matching (file, cancellable, ret, f->spec, f->depth);
-  g_task_return_pointer (task, g_steal_pointer (&ret), (GDestroyNotify)g_ptr_array_unref);
-}
-
-/**
- * ide_g_file_find_with_depth_async:
- * @file: a #IdeGlib
- * @pattern: the glob pattern to search for using GPatternSpec
- * @max_depth: maximum tree depth to search
- * @cancellable: (nullable): a #GCancellable or %NULL
- * @callback: a callback to execute upon completion
- * @user_data: closure data for @callback
- *
- * Searches descendants of @file for files matching @pattern.
- *
- * Only up to @max_depth subdirectories will be searched. However, if
- * @max_depth is zero, then all directories will be searched.
- *
- * You may only match on the filename, not the directory.
- *
- * Since: 3.30
- */
-void
-ide_g_file_find_with_depth_async (GFile               *file,
-                                  const gchar         *pattern,
-                                  guint                depth,
-                                  GCancellable        *cancellable,
-                                  GAsyncReadyCallback  callback,
-                                  gpointer             user_data)
-{
-  g_autoptr(GTask) task = NULL;
-  Find *f;
-
-  g_return_if_fail (G_IS_FILE (file));
-  g_return_if_fail (pattern != NULL);
-  g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
-
-  if (depth == 0)
-    depth = G_MAXUINT;
-
-  task = g_task_new (file, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_g_file_find_async);
-  g_task_set_priority (task, G_PRIORITY_LOW + 100);
-
-  f = g_slice_new0 (Find);
-  f->spec = g_pattern_spec_new (pattern);
-  f->depth = depth;
-  g_task_set_task_data (task, f, (GDestroyNotify)find_free);
-
-  if (f->spec == NULL)
-    {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_INVAL,
-                               "Invalid pattern spec: %s",
-                               pattern);
-      return;
-    }
-
-  g_task_run_in_thread (task, ide_g_file_find_worker);
+  populate_descendants_matching (file, cancellable, ret, spec);
+  ide_task_return_pointer (task, g_steal_pointer (&ret), (GDestroyNotify)g_ptr_array_unref);
 }
 
 /**
@@ -590,7 +514,31 @@ ide_g_file_find_async (GFile               *file,
                        GAsyncReadyCallback  callback,
                        gpointer             user_data)
 {
-  ide_g_file_find_with_depth_async (file, pattern, G_MAXUINT, cancellable, callback, user_data);
+  g_autoptr(IdeTask) task = NULL;
+  g_autoptr(GPatternSpec) spec = NULL;
+
+  g_return_if_fail (G_IS_FILE (file));
+  g_return_if_fail (pattern != NULL);
+  g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
+
+  task = ide_task_new (file, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_g_file_find_async);
+  ide_task_set_priority (task, G_PRIORITY_LOW + 100);
+
+  spec = g_pattern_spec_new (pattern);
+
+  if (spec == NULL)
+    {
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_INVAL,
+                                 "Invalid pattern spec: %s",
+                                 pattern);
+      return;
+    }
+
+  ide_task_set_task_data (task, g_steal_pointer (&spec), (GDestroyNotify)g_pattern_spec_free);
+  ide_task_run_in_thread (task, ide_g_file_find_worker);
 }
 
 /**
@@ -611,9 +559,9 @@ ide_g_file_find_finish (GFile         *file,
   GPtrArray *ret;
 
   g_return_val_if_fail (G_IS_FILE (file), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (IDE_IS_TASK (result), NULL);
 
-  ret = g_task_propagate_pointer (G_TASK (result), error);
+  ret = ide_task_propagate_pointer (IDE_TASK (result), error);
 
   return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
