@@ -1,6 +1,6 @@
 /* ide-glib.h
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,12 @@ G_BEGIN_DECLS
   ({ IDE_PTR_ARRAY_CLEAR_FREE_FUNC (*(arptr)); \
      g_steal_pointer ((arptr)); })
 
+#define ide_strv_empty0(strv) (((strv) == NULL) || ((strv)[0] == NULL))
+
+IDE_AVAILABLE_IN_3_30
+gboolean     ide_environ_parse                        (const gchar          *pair,
+                                                       gchar               **key,
+                                                       gchar               **value);
 IDE_AVAILABLE_IN_ALL
 const gchar *ide_gettext                              (const gchar          *message);
 IDE_AVAILABLE_IN_ALL
