@@ -3,7 +3,7 @@
 #
 # cargo_plugin.py
 #
-# Copyright © 2016 Christian Hergert <chris@dronelabs.com>
+# Copyright 2016 Christian Hergert <chris@dronelabs.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -103,7 +103,6 @@ class CargoPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
 
         cargo_toml = build_system.props.project_file.get_path()
         config = pipeline.get_configuration()
-        system_type = config.get_device().get_system_type()
         builddir = pipeline.get_builddir()
         runtime = config.get_runtime()
 
@@ -119,7 +118,7 @@ class CargoPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
         fetch_launcher.push_argv(cargo_toml)
         self.track(pipeline.connect_launcher(Ide.BuildPhase.DOWNLOADS, 0, fetch_launcher))
 
-        # Fetch dependencies so that we no longer need network access
+        # Now create our launcher to build the project
         build_launcher = pipeline.create_launcher()
         build_launcher.setenv('CARGO_TARGET_DIR', builddir, True)
         build_launcher.push_argv(cargo)
@@ -130,9 +129,9 @@ class CargoPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
         build_launcher.push_argv('--message-format')
         build_launcher.push_argv('human')
 
-        if Ide.get_system_type() != system_type:
+        if not pipeline.is_native():
             build_launcher.push_argv('--target')
-            build_launcher.push_argv(system_type)
+            build_launcher.push_argv(pipeline.get_host_triplet().get_full_name())
 
         if config.props.parallelism > 0:
             build_launcher.push_argv('-j{}'.format(config.props.parallelism))
@@ -150,8 +149,13 @@ class CargoPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
         build_stage = Ide.BuildStageLauncher.new(context, build_launcher)
         build_stage.set_name(_("Building project"))
         build_stage.set_clean_launcher(clean_launcher)
+        build_stage.connect('query', self._query)
         self.track(pipeline.connect(Ide.BuildPhase.BUILD, 0, build_stage))
 
+    def _query(self, stage, pipeline, cancellable):
+        # Always defer to cargo to check if build is needed
+        stage.set_completed(False)
+
 class CargoBuildTarget(Ide.Object, Ide.BuildTarget):
 
     def do_get_install_directory(self):
