@@ -64,7 +64,7 @@ gbp_deviced_deploy_strategy_load_async (IdeDeployStrategy   *strategy,
                                         gpointer             user_data)
 {
   GbpDevicedDeployStrategy *self = (GbpDevicedDeployStrategy *)strategy;
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   IdeConfiguration *config;
   IdeDevice *device;
 
@@ -74,8 +74,8 @@ gbp_deviced_deploy_strategy_load_async (IdeDeployStrategy   *strategy,
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, gbp_deviced_deploy_strategy_load_async);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, gbp_deviced_deploy_strategy_load_async);
 
   config = ide_build_pipeline_get_configuration (pipeline);
 
@@ -83,16 +83,16 @@ gbp_deviced_deploy_strategy_load_async (IdeDeployStrategy   *strategy,
       !GBP_IS_DEVICED_DEVICE (device) ||
       !GBP_IS_FLATPAK_MANIFEST (config))
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_NOT_SUPPORTED,
-                               "%s is not supported by %s",
-                               G_OBJECT_TYPE_NAME (device),
-                               G_OBJECT_TYPE_NAME (self));
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_NOT_SUPPORTED,
+                                 "%s is not supported by %s",
+                                 G_OBJECT_TYPE_NAME (device),
+                                 G_OBJECT_TYPE_NAME (self));
       IDE_EXIT;
     }
 
-  g_task_return_boolean (task, TRUE);
+  ide_task_return_boolean (task, TRUE);
 
   IDE_EXIT;
 }
@@ -104,18 +104,18 @@ deploy_install_bundle_cb (GObject      *object,
 {
   GbpDevicedDevice *device = (GbpDevicedDevice *)object;
   g_autoptr(GError) error = NULL;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
 
   IDE_ENTRY;
 
   g_assert (GBP_IS_DEVICED_DEVICE (device));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   if (!gbp_deviced_device_install_bundle_finish (device, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
-    g_task_return_boolean (task, TRUE);
+    ide_task_return_boolean (task, TRUE);
 
   IDE_EXIT;
 }
@@ -139,7 +139,7 @@ deploy_wait_check_cb (GObject      *object,
                       gpointer      user_data)
 {
   IdeSubprocess *subprocess = (IdeSubprocess *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
   DeployState *state;
 
@@ -147,17 +147,17 @@ deploy_wait_check_cb (GObject      *object,
 
   g_assert (IDE_IS_SUBPROCESS (subprocess));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
-  state = g_task_get_task_data (task);
+  state = ide_task_get_task_data (task);
 
   if (!ide_subprocess_wait_check_finish (subprocess, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
     gbp_deviced_device_install_bundle_async (state->device,
                                              state->flatpak_path,
                                              deploy_progress_cb, state, NULL,
-                                             g_task_get_cancellable (task),
+                                             ide_task_get_cancellable (task),
                                              deploy_install_bundle_cb,
                                              g_object_ref (task));
 
@@ -171,7 +171,7 @@ deploy_get_commit_cb (GObject      *object,
 {
   GbpDevicedDevice *device = (GbpDevicedDevice *)object;
   g_autoptr(IdeSubprocessLauncher) launcher = NULL;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autofree gchar *commit_id = NULL;
   g_autofree gchar *dest_path = NULL;
   g_autofree gchar *name = NULL;
@@ -179,6 +179,7 @@ deploy_get_commit_cb (GObject      *object,
   g_autofree gchar *staging_dir = NULL;
   g_autoptr(IdeSubprocess) subprocess = NULL;
   g_autoptr(GError) error = NULL;
+  g_autoptr(IdeTriplet) triplet = NULL;
   IdeConfiguration *config;
   const gchar *arch;
   const gchar *app_id;
@@ -190,9 +191,9 @@ deploy_get_commit_cb (GObject      *object,
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (GBP_IS_DEVICED_DEVICE (device));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
-  state = g_task_get_task_data (task);
+  state = ide_task_get_task_data (task);
   g_assert (state != NULL);
   g_assert (IDE_IS_BUILD_PIPELINE (state->pipeline));
 
@@ -200,7 +201,8 @@ deploy_get_commit_cb (GObject      *object,
 
   context = ide_object_get_context (IDE_OBJECT (state->pipeline));
   config = ide_build_pipeline_get_configuration (state->pipeline);
-  arch = ide_build_pipeline_get_arch (state->pipeline);
+  triplet = ide_build_pipeline_get_host_triplet (state->pipeline);
+  arch = ide_triplet_get_arch (triplet);
   staging_dir = gbp_flatpak_get_staging_dir (state->pipeline);
   repo_dir = gbp_flatpak_get_repo_dir (context);
   app_id = ide_configuration_get_app_id (config);
@@ -243,10 +245,10 @@ deploy_get_commit_cb (GObject      *object,
   ide_build_pipeline_attach_pty (state->pipeline, launcher);
 
   if (!(subprocess = ide_subprocess_launcher_spawn (launcher, NULL, &error)))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
     ide_subprocess_wait_check_async (subprocess,
-                                     g_task_get_cancellable (task),
+                                     ide_task_get_cancellable (task),
                                      deploy_wait_check_cb,
                                      g_object_ref (task));
 
@@ -260,7 +262,7 @@ deploy_commit_cb (GObject      *object,
 {
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
   g_autoptr(GError) error = NULL;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   GCancellable *cancellable;
   DeployState *state;
 
@@ -268,7 +270,7 @@ deploy_commit_cb (GObject      *object,
 
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (G_IS_ASYNC_RESULT (result));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   /*
    * If we successfully exported the build to a repo, we can now check
@@ -276,11 +278,11 @@ deploy_commit_cb (GObject      *object,
    * some data transfer by building a static-delta.
    */
 
-  cancellable = g_task_get_cancellable (task);
-  state = g_task_get_task_data (task);
+  cancellable = ide_task_get_cancellable (task);
+  state = ide_task_get_task_data (task);
 
   if (!ide_build_pipeline_build_finish (pipeline, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&task));
   else
     gbp_deviced_device_get_commit_async (state->device,
                                          state->app_id,
@@ -302,7 +304,8 @@ gbp_deviced_deploy_strategy_deploy_async (IdeDeployStrategy     *strategy,
                                           gpointer               user_data)
 {
   GbpDevicedDeployStrategy *self = (GbpDevicedDeployStrategy *)strategy;
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
+  g_autoptr(IdeTriplet) triplet = NULL;
   IdeConfiguration *config;
   DeployState *state;
   const gchar *app_id;
@@ -315,12 +318,13 @@ gbp_deviced_deploy_strategy_deploy_async (IdeDeployStrategy     *strategy,
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, gbp_deviced_deploy_strategy_deploy_async);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, gbp_deviced_deploy_strategy_deploy_async);
 
   config = ide_build_pipeline_get_configuration (pipeline);
   device = ide_build_pipeline_get_device (pipeline);
-  arch = ide_build_pipeline_get_arch (pipeline);
+  triplet = ide_build_pipeline_get_host_triplet (pipeline);
+  arch = ide_triplet_get_arch (triplet);
   app_id = ide_configuration_get_app_id (config);
 
   g_assert (GBP_IS_FLATPAK_MANIFEST (config));
@@ -333,7 +337,7 @@ gbp_deviced_deploy_strategy_deploy_async (IdeDeployStrategy     *strategy,
   state->progress = progress;
   state->progress_data = progress_data;
   state->progress_data_destroy = progress_data_destroy;
-  g_task_set_task_data (task, state, (GDestroyNotify)deploy_state_free);
+  ide_task_set_task_data (task, state, (GDestroyNotify)deploy_state_free);
 
   /*
    * First make sure we've built up to the point where we have a
