@@ -604,6 +604,7 @@ gbp_flatpak_runtime_provider_bootstrap_async (IdeRuntimeProvider  *provider,
   g_autofree gchar *arch = NULL;
   g_autofree gchar *branch = NULL;
   g_autoptr(IdeTask) task = NULL;
+  g_autoptr(IdeTriplet) triplet = NULL;
   IdeConfiguration *config;
   BootstrapState *state;
   const gchar *runtime_id;
@@ -619,7 +620,8 @@ gbp_flatpak_runtime_provider_bootstrap_async (IdeRuntimeProvider  *provider,
   ide_task_set_source_tag (task, gbp_flatpak_runtime_provider_bootstrap_async);
   ide_task_set_priority (task, G_PRIORITY_LOW);
 
-  build_arch = ide_build_pipeline_get_arch (pipeline);
+  triplet = ide_build_pipeline_get_host_triplet (pipeline);
+  build_arch = ide_triplet_get_arch (triplet);
   config = ide_build_pipeline_get_configuration (pipeline);
   runtime_id = ide_configuration_get_runtime_id (config);
 
