@@ -1,6 +1,6 @@
 /* gb-flatpak-runtime.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,6 +58,12 @@ enum {
 
 static GParamSpec *properties [N_PROPS];
 
+static inline gboolean
+strv_empty (gchar **strv)
+{
+  return strv == NULL || strv[0] == NULL;
+}
+
 static const gchar *
 get_builddir (GbpFlatpakRuntime *self)
 {
@@ -69,7 +75,6 @@ get_builddir (GbpFlatpakRuntime *self)
   return builddir;
 }
 
-
 static gchar *
 get_staging_directory (GbpFlatpakRuntime *self)
 {
@@ -236,8 +241,10 @@ gbp_flatpak_runtime_create_launcher (IdeRuntime  *runtime,
           ide_subprocess_launcher_push_argv (ret, filesystem_option_src);
           ide_subprocess_launcher_push_argv (ret, filesystem_option_build);
         }
+
       new_environ = ide_configuration_get_environ (IDE_CONFIGURATION (configuration));
-      if (g_strv_length (new_environ) > 0)
+
+      if (!strv_empty (new_environ))
         {
           for (guint i = 0; new_environ[i]; i++)
             {
@@ -262,6 +269,23 @@ gbp_flatpak_runtime_create_launcher (IdeRuntime  *runtime,
   return ret;
 }
 
+static gboolean
+is_a_shell (const gchar *str)
+{
+  static const gchar *suffixes[] = { "/bash", "/sh", "/dash", "/zsh" };
+
+  if (str)
+    {
+      for (guint i = 0; i < G_N_ELEMENTS (suffixes); i++)
+        {
+          if (g_str_has_suffix (str, suffixes[i]))
+            return TRUE;
+        }
+    }
+
+  return FALSE;
+}
+
 static gchar *
 get_binary_name (GbpFlatpakRuntime *self,
                  IdeBuildTarget    *build_target)
@@ -269,6 +293,16 @@ get_binary_name (GbpFlatpakRuntime *self,
   IdeContext *context = ide_object_get_context (IDE_OBJECT (self));
   IdeConfigurationManager *config_manager = ide_context_get_configuration_manager (context);
   IdeConfiguration *config = ide_configuration_manager_get_current (config_manager);
+  g_autofree gchar *build_target_name = ide_build_target_get_name (build_target);
+  g_auto(GStrv) argv = ide_build_target_get_argv (build_target);
+
+  /* XXX: temporary workaround while we come up with how to
+   *      spawn shells in the mount namespace appropriately.
+   */
+  if (is_a_shell (build_target_name))
+    return g_steal_pointer (&build_target_name);
+  else if (argv && is_a_shell (argv[0]))
+    return g_strdup (argv[0]);
 
   if (GBP_IS_FLATPAK_MANIFEST (config))
     {
@@ -280,13 +314,8 @@ get_binary_name (GbpFlatpakRuntime *self,
     }
 
   /* Use the build target name if there's no command in the manifest */
-  {
-    g_autofree gchar *build_target_name = NULL;
-
-    build_target_name = ide_build_target_get_name (build_target);
-    if (!dzl_str_empty0 (build_target_name))
-      return g_steal_pointer (&build_target_name);
-  }
+  if (!dzl_str_empty0 (build_target_name))
+    return g_steal_pointer (&build_target_name);
 
   /* Use the project name as a last resort */
   {
