@@ -1,6 +1,6 @@
 /* gbp-meson-pipeline-addin.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,8 +99,7 @@ gbp_meson_pipeline_addin_load (IdeBuildPipelineAddin *addin,
 
   if (ninja == NULL)
     {
-      ide_context_warning (context,
-                           _("A Meson-based project is loaded but Ninja could not be found."));
+      g_debug ("Failed to locate ninja. Meson building is disabled.");
       IDE_EXIT;
     }
 
@@ -118,10 +117,6 @@ gbp_meson_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   if (NULL == (meson = ide_configuration_getenv (config, "MESON")))
     meson = "meson";
 
-  if (!ide_runtime_contains_program_in_path (runtime, meson, NULL))
-    ide_context_warning (context,
-                         _("A Meson-based project is loaded but meson could not be found."));
-
   /* Setup our meson configure stage. */
 
   ide_subprocess_launcher_push_argv (config_launcher, meson);
