@@ -393,7 +393,6 @@ completion_item_free (CompletionItem *item)
 {
   g_clear_pointer (&item->label, g_free);
   g_clear_pointer (&item->define, ide_xml_rng_define_unref);
-  g_slice_free (CompletionItem, item);
 }
 
 static MatchingState *
@@ -462,8 +461,6 @@ matching_state_free (MatchingState *state)
   g_clear_pointer (&state->prefix, g_free);
   g_clear_pointer (&state->children, g_ptr_array_unref);
   g_clear_pointer (&state->stack, g_array_unref);
-
-  g_slice_free (MatchingState, state);
 }
 
 static MatchingState *
