@@ -43,12 +43,13 @@ ide_xml_path_prepend_node (IdeXmlPath       *self,
 void
 ide_xml_path_dump (IdeXmlPath *self)
 {
+  IdeXmlSymbolNode *node;
+
   g_return_if_fail (self);
 
   for (gint i = 0; i < self->nodes->len; ++i)
     {
-      IdeXmlSymbolNode *node = g_ptr_array_index (self->nodes, i);
-
+      node = g_ptr_array_index (self->nodes, i);
       ide_xml_symbol_node_print (node, 0, FALSE, TRUE, TRUE);
     }
 }
@@ -104,7 +105,7 @@ ide_xml_path_free (IdeXmlPath *self)
   g_assert (self);
   g_assert_cmpint (self->ref_count, ==, 0);
 
-  g_clear_pointer (&self->nodes, g_ptr_array_unref);
+  g_ptr_array_unref (self->nodes);
 
   g_slice_free (IdeXmlPath, self);
 }
@@ -113,7 +114,7 @@ IdeXmlPath *
 ide_xml_path_ref (IdeXmlPath *self)
 {
   g_return_val_if_fail (self, NULL);
-  g_return_val_if_fail (self->ref_count > 0, NULL);
+  g_return_val_if_fail (self->ref_count, NULL);
 
   g_atomic_int_inc (&self->ref_count);
 
@@ -124,7 +125,7 @@ void
 ide_xml_path_unref (IdeXmlPath *self)
 {
   g_return_if_fail (self);
-  g_return_if_fail (self->ref_count > 0);
+  g_return_if_fail (self->ref_count);
 
   if (g_atomic_int_dec_and_test (&self->ref_count))
     ide_xml_path_free (self);
